==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/id_id/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Menambahkan';
$lang['AdminDepartments.edit.text_delete'] = 'Menghapus';
$lang['AdminDepartments.edit.heading_default'] = 'Default';
$lang['AdminDepartments.edit.heading_value'] = 'Nilai';
$lang['AdminDepartments.edit.heading_name'] = 'Nama';
$lang['AdminDepartments.edit.heading_options'] = 'Pilihan';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Hapus Otomatis';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Terenkripsi';
$lang['AdminDepartments.edit.heading_client_add'] = 'Klien dapat Menambahkan';
$lang['AdminDepartments.edit.heading_step'] = 'Langkah';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Jenis';
$lang['AdminDepartments.edit.heading_visibility'] = 'Visibilitas';
$lang['AdminDepartments.edit.heading_description'] = 'Deskripsi';
$lang['AdminDepartments.edit.heading_label'] = 'Label';
$lang['AdminDepartments.edit.no_results'] = 'Tidak ada bidang khusus di departemen ini.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Apakah Anda yakin ingin menghapus bidang khusus ini? Semua data yang terkait dengan bidang ini akan dihapus. Jika Anda ingin menyembunyikan bidang ini dan menyimpan datanya, ubah Visibilitasnya menjadi Hanya Staf.';
$lang['AdminDepartments.edit.field_add_field'] = 'Tambahkan Bidang';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Edit Departemen';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Tanggapan Penutupan Tiket Otomatis';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Kirim Pengingat ke Tiket dengan Prioritas';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Kirim Pengingat ke Tiket dengan Status';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Kirim Pengingat Tiket Secara Otomatis';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Hapus Tiket Secara Otomatis';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Tutup Tiket Secara Otomatis';
$lang['AdminDepartments.edit.field_port'] = 'Pelabuhan';
$lang['AdminDepartments.edit.field_pass'] = 'Lulus';
$lang['AdminDepartments.edit.field_user'] = 'Pengguna';
$lang['AdminDepartments.edit.field_host'] = 'Tuan rumah';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Tandai Pesan sebagai';
$lang['AdminDepartments.edit.field_box_name'] = 'Nama Kotak';
$lang['AdminDepartments.edit.field_security'] = 'Keamanan';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Ukuran Lampiran Maks';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Jenis Lampiran yang Didukung';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Menyertakan lampiran yang didukung dalam pemberitahuan tiket';
$lang['AdminDepartments.edit.field_default_priority'] = 'Prioritas Default';
$lang['AdminDepartments.edit.field_piping_config'] = 'Konfigurasi Perpipaan';
$lang['AdminDepartments.edit.field_method'] = 'Penanganan Email';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Secara otomatis mengalihkan status tiket pada balasan admin';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Kirim Email Tanggapan Otomatis untuk Tiket Baru';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Timpa alamat dari yang ditetapkan di templat email dengan alamat email yang ditetapkan untuk departemen ini';
$lang['AdminDepartments.edit.field_email'] = 'Email';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Memerlukan Verifikasi Manusia untuk pengguna yang tidak diautentikasi';
$lang['AdminDepartments.edit.field_clients_only'] = 'Hanya mengizinkan klien untuk membuka atau membalas tiket';
$lang['AdminDepartments.edit.field_description'] = 'Deskripsi';
$lang['AdminDepartments.edit.field_name'] = 'Nama';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Bidang Khusus';
$lang['AdminDepartments.edit.tab_general'] = 'Umum';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Edit Departemen';
$lang['AdminDepartments.add.text_add'] = 'Menambahkan';
$lang['AdminDepartments.add.text_delete'] = 'Menghapus';
$lang['AdminDepartments.add.heading_default'] = 'Default';
$lang['AdminDepartments.add.heading_value'] = 'Nilai';
$lang['AdminDepartments.add.heading_name'] = 'Nama';
$lang['AdminDepartments.add.heading_options'] = 'Pilihan';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Hapus Otomatis';
$lang['AdminDepartments.add.heading_encrypted'] = 'Terenkripsi';
$lang['AdminDepartments.add.heading_client_add'] = 'Klien dapat Menambahkan';
$lang['AdminDepartments.add.heading_step'] = 'Langkah';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Jenis';
$lang['AdminDepartments.add.heading_visibility'] = 'Visibilitas';
$lang['AdminDepartments.add.heading_description'] = 'Deskripsi';
$lang['AdminDepartments.add.heading_label'] = 'Label';
$lang['AdminDepartments.add.field_add_field'] = 'Tambahkan Bidang';
$lang['AdminDepartments.add.field_addsubmit'] = 'Tambahkan Departemen';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Tanggapan Penutupan Tiket Otomatis';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Kirim Pengingat ke Tiket dengan Prioritas';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Kirim Pengingat ke Tiket dengan Status';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Kirim Pengingat Tiket Secara Otomatis';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Hapus Tiket Secara Otomatis';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Tutup Tiket Secara Otomatis';
$lang['AdminDepartments.add.field_port'] = 'Pelabuhan';
$lang['AdminDepartments.add.field_pass'] = 'Lulus';
$lang['AdminDepartments.add.field_user'] = 'Pengguna';
$lang['AdminDepartments.add.field_host'] = 'Tuan rumah';
$lang['AdminDepartments.add.field_mark_messages'] = 'Tandai Pesan sebagai';
$lang['AdminDepartments.add.field_box_name'] = 'Nama Kotak';
$lang['AdminDepartments.add.field_security'] = 'Keamanan';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Ukuran Lampiran Maks';
$lang['AdminDepartments.add.field_attachment_types'] = 'Jenis Lampiran yang Didukung';
$lang['AdminDepartments.add.field_include_attachments'] = 'Menyertakan lampiran yang didukung dalam pemberitahuan tiket';
$lang['AdminDepartments.add.field_default_priority'] = 'Prioritas Default';
$lang['AdminDepartments.add.field_piping_config'] = 'Konfigurasi Perpipaan';
$lang['AdminDepartments.add.field_method'] = 'Penanganan Email';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Status tiket transisi secara otomatis pada balasan admin';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Kirim Email Tanggapan Otomatis untuk Tiket Baru';
$lang['AdminDepartments.add.field_override_from_email'] = 'Timpa alamat dari yang ditetapkan di templat email dengan alamat email yang ditetapkan untuk departemen ini';
$lang['AdminDepartments.add.field_email'] = 'Email';
$lang['AdminDepartments.add.field_require_captcha'] = 'Memerlukan Verifikasi Manusia untuk pengguna yang tidak diautentikasi';
$lang['AdminDepartments.add.field_clients_only'] = 'Hanya mengizinkan klien untuk membuka atau membalas tiket';
$lang['AdminDepartments.add.field_description'] = 'Deskripsi';
$lang['AdminDepartments.add.field_name'] = 'Nama';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Bidang Khusus';
$lang['AdminDepartments.add.tab_general'] = 'Umum';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Tambahkan Departemen';
$lang['AdminDepartments.!text.remove_response'] = 'Menghapus';
$lang['AdminDepartments.!text.no_selected_response'] = 'Tidak ada respons tutup otomatis yang dipilih.';
$lang['AdminDepartments.!text.add_response'] = 'Mengatur Respons yang Telah Ditetapkan Sebelumnya untuk Menutup Otomatis';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Jika tiket ditutup, data lapangan akan dihapus secara otomatis. Data tersebut tidak akan lagi dapat dilihat oleh staf.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Apakah klien dapat mengirimkan bidang atau tidak, jika salah, klien hanya akan dapat membaca bidang tersebut.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Ukuran maksimum lampiran untuk disertakan dalam MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Daftar ekstensi yang didukung dipisahkan dengan koma (mis. zip, jpg, png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Server email memiliki batasan ukuran lampiran dan jenis file. Untuk mengurangi risiko email ditolak, harap sertakan batasan jenis dan ukuran lampiran. Untuk memastikan klien mengetahui lampiran yang tidak disertakan, gunakan tag {ticket.reply_has_attachments} dalam pemberitahuan tiket.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Mengubah status menjadi %1$s ketika anggota staf membalas.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Menghilangkan centang pada kotak ini menunjukkan bahwa tiket baru yang dibuat untuk departemen ini (melalui email atau klien) tidak akan mengirimkan pemberitahuan balasan kepada klien atau staf melalui email Ticket Received atau email Staff Ticket Updated, masing-masing.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Untuk semua tiket dengan status selain %1$s, pengingat akan dikirim ke bagian lain jika tidak ada balasan dalam jangka waktu yang dipilih.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Semua tiket dengan status %1$s akan dihapus secara otomatis setelah berada dalam status tersebut selama jangka waktu tertentu.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Semua tiket dengan status selain %1$ yang balasan terakhirnya berasal dari anggota staf akan ditutup secara otomatis jika tidak ada balasan yang masuk dalam jangka waktu yang dipilih.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Atur jalur piping Anda seperti yang ditunjukkan, tetapi pastikan untuk menggunakan jalur yang benar ke PHP di server Anda. Pastikan pipe.php dapat dieksekusi. Anda mungkin juga perlu mengedit pipe.php untuk menyertakan hashbang pada baris 1 yang akan terlihat seperti ini: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Tidak ada staf yang ditugaskan di departemen ini.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Staf';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Staf yang Ditugaskan';
$lang['AdminDepartments.index.no_results'] = 'Tidak ada departemen.';
$lang['AdminDepartments.index.confirm_delete'] = 'Departemen dengan tiket yang ditugaskan padanya tidak dapat dihapus hingga semua tiket telah ditugaskan kembali ke departemen lain. Apakah Anda yakin ingin menghapus departemen ini?';
$lang['AdminDepartments.index.option_delete'] = 'Menghapus';
$lang['AdminDepartments.index.option_edit'] = 'Sunting';
$lang['AdminDepartments.index.heading_options'] = 'Pilihan';
$lang['AdminDepartments.index.heading_default_priority'] = 'Prioritas Default';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Staf yang Ditugaskan';
$lang['AdminDepartments.index.heading_email'] = 'Email';
$lang['AdminDepartments.index.heading_description'] = 'Deskripsi';
$lang['AdminDepartments.index.heading_name'] = 'Nama';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Departemen';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Tambahkan Departemen';
$lang['AdminDepartments.edit.page_title'] = 'Manajer Dukungan > Departemen > Edit Departemen';
$lang['AdminDepartments.add.page_title'] = 'Manajer Dukungan > Departemen > Tambah Departemen';
$lang['AdminDepartments.index.page_title'] = 'Manajer Dukungan > Departemen';
$lang['AdminDepartments.!success.department_deleted'] = 'Departemen %1$ berhasil dihapus.';
$lang['AdminDepartments.!success.department_updated'] = 'Departemen %1$ berhasil diperbarui.';
$lang['AdminDepartments.!success.department_created'] = 'Departemen %1$ telah berhasil dibuat.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/id_id/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Menambahkan';
$lang['AdminDepartments.edit.text_delete'] = 'Menghapus';
$lang['AdminDepartments.edit.heading_default'] = 'Default';
$lang['AdminDepartments.edit.heading_value'] = 'Nilai';
$lang['AdminDepartments.edit.heading_name'] = 'Nama';
$lang['AdminDepartments.edit.heading_options'] = 'Pilihan';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Hapus Otomatis';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Terenkripsi';
$lang['AdminDepartments.edit.heading_client_add'] = 'Klien dapat Menambahkan';
$lang['AdminDepartments.edit.heading_step'] = 'Langkah';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Jenis';
$lang['AdminDepartments.edit.heading_visibility'] = 'Visibilitas';
$lang['AdminDepartments.edit.heading_description'] = 'Deskripsi';
$lang['AdminDepartments.edit.heading_label'] = 'Label';
$lang['AdminDepartments.edit.no_results'] = 'Tidak ada bidang khusus di departemen ini.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Apakah Anda yakin ingin menghapus bidang khusus ini? Semua data yang terkait dengan bidang ini akan dihapus. Jika Anda ingin menyembunyikan bidang ini dan menyimpan datanya, ubah Visibilitasnya menjadi Hanya Staf.';
$lang['AdminDepartments.edit.field_add_field'] = 'Tambahkan Bidang';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Edit Departemen';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Tanggapan Penutupan Tiket Otomatis';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Kirim Pengingat ke Tiket dengan Prioritas';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Kirim Pengingat ke Tiket dengan Status';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Kirim Pengingat Tiket Secara Otomatis';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Hapus Tiket Secara Otomatis';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Tutup Tiket Secara Otomatis';
$lang['AdminDepartments.edit.field_port'] = 'Pelabuhan';
$lang['AdminDepartments.edit.field_pass'] = 'Lulus';
$lang['AdminDepartments.edit.field_user'] = 'Pengguna';
$lang['AdminDepartments.edit.field_host'] = 'Tuan rumah';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Tandai Pesan sebagai';
$lang['AdminDepartments.edit.field_box_name'] = 'Nama Kotak';
$lang['AdminDepartments.edit.field_security'] = 'Keamanan';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Ukuran Lampiran Maks';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Jenis Lampiran yang Didukung';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Menyertakan lampiran yang didukung dalam pemberitahuan tiket';
$lang['AdminDepartments.edit.field_default_priority'] = 'Prioritas Default';
$lang['AdminDepartments.edit.field_piping_config'] = 'Konfigurasi Perpipaan';
$lang['AdminDepartments.edit.field_method'] = 'Penanganan Email';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Secara otomatis mengalihkan status tiket pada balasan admin';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Kirim Email Tanggapan Otomatis untuk Tiket Baru';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Timpa alamat dari yang ditetapkan di templat email dengan alamat email yang ditetapkan untuk departemen ini';
$lang['AdminDepartments.edit.field_email'] = 'Email';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Memerlukan Verifikasi Manusia untuk pengguna yang tidak diautentikasi';
$lang['AdminDepartments.edit.field_clients_only'] = 'Hanya mengizinkan klien untuk membuka atau membalas tiket';
$lang['AdminDepartments.edit.field_description'] = 'Deskripsi';
$lang['AdminDepartments.edit.field_name'] = 'Nama';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Bidang Khusus';
$lang['AdminDepartments.edit.tab_general'] = 'Umum';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Edit Departemen';
$lang['AdminDepartments.add.text_add'] = 'Menambahkan';
$lang['AdminDepartments.add.text_delete'] = 'Menghapus';
$lang['AdminDepartments.add.heading_default'] = 'Default';
$lang['AdminDepartments.add.heading_value'] = 'Nilai';
$lang['AdminDepartments.add.heading_name'] = 'Nama';
$lang['AdminDepartments.add.heading_options'] = 'Pilihan';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Hapus Otomatis';
$lang['AdminDepartments.add.heading_encrypted'] = 'Terenkripsi';
$lang['AdminDepartments.add.heading_client_add'] = 'Klien dapat Menambahkan';
$lang['AdminDepartments.add.heading_step'] = 'Langkah';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Jenis';
$lang['AdminDepartments.add.heading_visibility'] = 'Visibilitas';
$lang['AdminDepartments.add.heading_description'] = 'Deskripsi';
$lang['AdminDepartments.add.heading_label'] = 'Label';
$lang['AdminDepartments.add.field_add_field'] = 'Tambahkan Bidang';
$lang['AdminDepartments.add.field_addsubmit'] = 'Tambahkan Departemen';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Tanggapan Penutupan Tiket Otomatis';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Kirim Pengingat ke Tiket dengan Prioritas';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Kirim Pengingat ke Tiket dengan Status';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Kirim Pengingat Tiket Secara Otomatis';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Hapus Tiket Secara Otomatis';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Tutup Tiket Secara Otomatis';
$lang['AdminDepartments.add.field_port'] = 'Pelabuhan';
$lang['AdminDepartments.add.field_pass'] = 'Lulus';
$lang['AdminDepartments.add.field_user'] = 'Pengguna';
$lang['AdminDepartments.add.field_host'] = 'Tuan rumah';
$lang['AdminDepartments.add.field_mark_messages'] = 'Tandai Pesan sebagai';
$lang['AdminDepartments.add.field_box_name'] = 'Nama Kotak';
$lang['AdminDepartments.add.field_security'] = 'Keamanan';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Ukuran Lampiran Maks';
$lang['AdminDepartments.add.field_attachment_types'] = 'Jenis Lampiran yang Didukung';
$lang['AdminDepartments.add.field_include_attachments'] = 'Menyertakan lampiran yang didukung dalam pemberitahuan tiket';
$lang['AdminDepartments.add.field_default_priority'] = 'Prioritas Default';
$lang['AdminDepartments.add.field_piping_config'] = 'Konfigurasi Perpipaan';
$lang['AdminDepartments.add.field_method'] = 'Penanganan Email';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Status tiket transisi secara otomatis pada balasan admin';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Kirim Email Tanggapan Otomatis untuk Tiket Baru';
$lang['AdminDepartments.add.field_override_from_email'] = 'Timpa alamat dari yang ditetapkan di templat email dengan alamat email yang ditetapkan untuk departemen ini';
$lang['AdminDepartments.add.field_email'] = 'Email';
$lang['AdminDepartments.add.field_require_captcha'] = 'Memerlukan Verifikasi Manusia untuk pengguna yang tidak diautentikasi';
$lang['AdminDepartments.add.field_clients_only'] = 'Hanya mengizinkan klien untuk membuka atau membalas tiket';
$lang['AdminDepartments.add.field_description'] = 'Deskripsi';
$lang['AdminDepartments.add.field_name'] = 'Nama';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Bidang Khusus';
$lang['AdminDepartments.add.tab_general'] = 'Umum';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Tambahkan Departemen';
$lang['AdminDepartments.!text.remove_response'] = 'Menghapus';
$lang['AdminDepartments.!text.no_selected_response'] = 'Tidak ada respons tutup otomatis yang dipilih.';
$lang['AdminDepartments.!text.add_response'] = 'Mengatur Respons yang Telah Ditetapkan Sebelumnya untuk Menutup Otomatis';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Jika tiket ditutup, data lapangan akan dihapus secara otomatis. Data tersebut tidak akan lagi dapat dilihat oleh staf.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Apakah klien dapat mengirimkan bidang atau tidak, jika salah, klien hanya akan dapat membaca bidang tersebut.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Ukuran maksimum lampiran untuk disertakan dalam MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Daftar ekstensi yang didukung dipisahkan dengan koma (mis. zip, jpg, png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Server email memiliki batasan ukuran lampiran dan jenis file. Untuk mengurangi risiko email ditolak, harap sertakan batasan jenis dan ukuran lampiran. Untuk memastikan klien mengetahui lampiran yang tidak disertakan, gunakan tag {ticket.reply_has_attachments} dalam pemberitahuan tiket.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Mengubah status menjadi %1$s ketika anggota staf membalas.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Menghilangkan centang pada kotak ini menunjukkan bahwa tiket baru yang dibuat untuk departemen ini (melalui email atau klien) tidak akan mengirimkan pemberitahuan balasan kepada klien atau staf melalui email Ticket Received atau email Staff Ticket Updated, masing-masing.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Untuk semua tiket dengan status selain %1$s, pengingat akan dikirim ke bagian lain jika tidak ada balasan dalam jangka waktu yang dipilih.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Semua tiket dengan status %1$s akan dihapus secara otomatis setelah berada dalam status tersebut selama jangka waktu tertentu.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Semua tiket dengan status selain %1$ yang balasan terakhirnya berasal dari anggota staf akan ditutup secara otomatis jika tidak ada balasan yang masuk dalam jangka waktu yang dipilih.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Atur jalur piping Anda seperti yang ditunjukkan, tetapi pastikan untuk menggunakan jalur yang benar ke PHP di server Anda. Pastikan pipe.php dapat dieksekusi. Anda mungkin juga perlu mengedit pipe.php untuk menyertakan hashbang pada baris 1 yang akan terlihat seperti ini: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Tidak ada staf yang ditugaskan di departemen ini.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Staf';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Staf yang Ditugaskan';
$lang['AdminDepartments.index.no_results'] = 'Tidak ada departemen.';
$lang['AdminDepartments.index.confirm_delete'] = 'Departemen dengan tiket yang ditugaskan padanya tidak dapat dihapus hingga semua tiket telah ditugaskan kembali ke departemen lain. Apakah Anda yakin ingin menghapus departemen ini?';
$lang['AdminDepartments.index.option_delete'] = 'Menghapus';
$lang['AdminDepartments.index.option_edit'] = 'Sunting';
$lang['AdminDepartments.index.heading_options'] = 'Pilihan';
$lang['AdminDepartments.index.heading_default_priority'] = 'Prioritas Default';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Staf yang Ditugaskan';
$lang['AdminDepartments.index.heading_email'] = 'Email';
$lang['AdminDepartments.index.heading_description'] = 'Deskripsi';
$lang['AdminDepartments.index.heading_name'] = 'Nama';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Departemen';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Tambahkan Departemen';
$lang['AdminDepartments.edit.page_title'] = 'Manajer Dukungan > Departemen > Edit Departemen';
$lang['AdminDepartments.add.page_title'] = 'Manajer Dukungan > Departemen > Tambah Departemen';
$lang['AdminDepartments.index.page_title'] = 'Manajer Dukungan > Departemen';
$lang['AdminDepartments.!success.department_deleted'] = 'Departemen %1$ berhasil dihapus.';
$lang['AdminDepartments.!success.department_updated'] = 'Departemen %1$ berhasil diperbarui.';
$lang['AdminDepartments.!success.department_created'] = 'Departemen %1$ telah berhasil dibuat.';
$lang['AdminDepartments.edit.field_priorities'] = 'Prioritas yang Tersedia';
$lang['AdminDepartments.add.field_priorities'] = 'Prioritas yang Tersedia';
$lang['AdminDepartments.edit.field_force_import'] = 'Impor Paksa';
$lang['AdminDepartments.add.field_force_import'] = 'Impor Paksa';
$lang['AdminDepartments.!success.department_imported'] = 'Departemen %1$s berhasil diimpor.';
